@@ -2,7 +2,7 @@ package Net::Whois::IP;
 
 
 ########################################
-#$Id: IP.pm,v 1.13 2005/12/06 18:58:50 ben Exp $
+#$Id: IP.pm,v 1.8 2003/06/30 15:57:19 ben Exp $
 ########################################
 
 use strict;
@@ -15,15 +15,9 @@ use Carp;
 @EXPORT = qw(
 	     whoisip_query
 	    );
-$VERSION = '1.00';
+$VERSION = '0.45';
 
-my %whois_servers = (
-	"RIPE"=>"whois.ripe.net",
-	"APNIC"=>"whois.apnic.net",
-	"KRNIC"=>"whois.krnic.net",
-	"LACNIC"=>"whois.lacnic.net",
-	"ARIN"=>"whois.arin.net",
-	);
+my %whois_servers = ("RIPE"=>"whois.ripe.net","APNIC"=>"whois.apnic.net","KRNIC"=>"whois.krnic.net","LACNIC"=>"whois.lacnic.net","ARIN"=>"whois.arin.net");
 
 ######################################
 # Public Subs
@@ -83,38 +77,20 @@ sub _do_lookup {
 
 sub _do_query{
     my($registrar,$ip,$multiple_flag) = @_;
-    my @response;
-    my $i =0;
-LOOP:while(1) {    
-      $i++;
-      my $sock = _get_connect($registrar);
-      print $sock "$ip\n";
-      @response = <$sock>;
-      close($sock);
-      if($#response < 0) {
-	#DO_DEBUG("No valid response recieved from $registrar -- attempt $i ");
-	if($i <=3) {
-	  next LOOP;
-	}else{
-	  croak("No valid response for 4th time... dying....");
-	}
-      }else{
-	last LOOP;
-      }
-    }
+    my $sock = _get_connect($registrar);
+    print $sock "$ip\n";
+    my @response = <$sock>;
+    close($sock);
 #Prevent killing the whois.arin.net --- they will disable an ip if greater than 40 queries per minute
     sleep(1);
     my %hash_response;
-    #DO_DEBUG("multiple flag = |$multiple_flag|");
     foreach my $line (@response) {
 	if($line =~ /^(.+):\s+(.+)$/) {
 	  if( ($multiple_flag) && ($multiple_flag ne "") ) {
 #Multiple_flag is set, so get all responses for a given record item
-	    #DO_DEBUG("Flag set ");
 	    push @{ $hash_response{$1} }, $2;
 	  }else{
 #Multiple_flag is not set, so only the last entry for any given record item
-	    #DO_DEBUG("Flag not set");
 	    $hash_response{$1} = $2;
 	   }
 	}
@@ -132,10 +108,11 @@ sub _do_processing {
     my $pattern1 = "TechPhone";
     my $pattern2 = "OrgTechPhone";
     if(($search_options) && ($search_options->[0] ne "") ) {
+      if($search_options eq "Name") {
 	$pattern1 = $search_options->[0];
 	$pattern2 = $search_options->[1];
+      }
     }
-    #DO_DEBUG("pattern1 = $pattern1 || pattern2 == $pattern2");
 		
 		
 
@@ -179,7 +156,6 @@ sub _get_connect {
 				     PeerAddr=>$whois_registrar,
 				     PeerPort=>'43',
 				     Timeout=>'60',
-#				     Blocking=>'0',
 				    );
     unless($sock) {
 	carp("Failed to Connect to $whois_registrar at port print -$@");
@@ -188,7 +164,6 @@ sub _get_connect {
 				      PeerAddr=>$whois_registrar,
 				      PeerPort=>'43',
 				      Timeout=>'60',
-#				      Blocking=>'0',
 				     );
 	unless($sock) {
 	    croak("Failed to Connect to $whois_registrar at port 43 for the second time - $@");
@@ -197,15 +172,15 @@ sub _get_connect {
     return($sock);
 }
 
-#sub DO_DEBUG {
-#    my(@stuff) = @_;
-#    my $date = scalar localtime;
-#    open(DEBUG,">>/tmp/Net.WhoisIP.log") or warn "Unable to open /tmp/$0.log";
-#    foreach my $item ( @stuff) {
-#        print DEBUG "$date|$item|\n";
-#    }
-#    close(DEBUG);
-#}
+sub DO_DEBUG {
+    my(@stuff) = @_;
+    my $date = scalar localtime;
+    open(DEBUG,">>/tmp/Net.WhoisIP.log") or warn "Unable to open /tmp/$0.log";
+    foreach my $item ( @stuff) {
+        print DEBUG "$date|$item|\n";
+    }
+    close(DEBUG);
+}
 
 
 1;
@@ -255,7 +230,7 @@ foreach ( sort keys %$response ){
 
 #$optonal_array_of_search_options set but not $optional_multiple_flag
 my $search_options = ["NetName","OrgName"];
-my $response = whois_query($ip,"",$search_options);
+my $response = whois_query($ip,,$search_options);
 foreach (sort keys(%{$response}) ) {
            print "$_ $response->{$_} \n";
 }
